- df
A data frame containing stratigraphic data.
Must include columns stratsection_name, stratlayer_order,
grainsize, depth, stratlayer_type, and SampleID.
- section_name
Character string giving the section name to filter "stratsection_name".
- label
Character strin gnaming the column to use for labels. Default is "SampleID".
- use_theme
A ggplot2 theme object to apply to the plot, e.g., "theme_avstrat".
- ylim
Numeric vector of length 2 giving y-axis limits (optional).
- depth_units
Units to use for depth (y-axis) scale, either "cm" (default) or "m".
- ybreaks
Number of breaks on the y-axis.